function [ measures ] = evaluate_tables_gf( tables, options, ntopk)

% function [ measures ] = evaluate_tables_gf( tables, options, ntopk)
% options = 1  OddsRatio
% options = 2  Chi2
% options = 3  DiffSup
% options = 4  DiffRatio
% the only difference with evaluate_tables_multifunc.m is that odds ratio here is made >=1
%
%
% EVALUATE_TABLES  Evaulate 2 by 2 contigency tables for a variety of measures
%        
% Evaluate each of a collection of 2 by 2 contingency tables according to 
% a variety of measures. The contingency table looks as follows:
%
%                   q (cases)       not q (controls)  row totals
%                 ----------------------------------------------
%            p     f11 (a)          f10 (b)            f1plus
%        not p     f01 (c)          f00 (d)            f0plus
%                 ----------------------------------------------
% column totals   fplus1 (cases)    fplus0 (controls)    N
%
% In terms of other common notation, a = f11, b = f10, c = f01, and d = f00.
% It is assumed that tables is a four by number of tables arrays, is passed 
% in the order f11, f10, f01, f00 or a b c d.
% 
% The measures array is a number of table by number of measures array 
% that gives the measure for each table. The labels of the measures are
% also returned. If the use_bonferroni flag is set to 1, then
% the pvalue is adjusted by multiplying it by the number of tables and
% taking the min with 1. This reduces the p-values to account for multiple
% hypothesis testing. If sort_flag is set to 1, then the results are sorted
% in decreasing order by -log( pvalue ). the table labels are reordered to
% match this sorting.
%
% [ measures measure_labels table_labels ] = evaluate_tables( tables, table_labels, num_tests, sort_flag );

% Default sort flag and the number of tests

%[ m n ] = size( table2);

num_tables = size( tables, 1 );

if nargin < 3
	ntopk = -1;
end

ntopk = min(ntopk,size(tables,1));

measures = zeros( num_tables, 1);

f11 = tables( :, 1 );
f10 = tables( :, 2 );
f01 = tables( :, 3 );
f00 = tables( :, 4 );

f1plus = f11 + f10;
f0plus = f01 + f00;
fplus1 = f11 + f01;
fplus0 = f10 + f00;
N = f1plus + f0plus;

thesig = 1;

% Compute OR

if(options == 1)
	thesig = 0;
	num = (f11+1).* (f00+1);
	denom = (f10+1) .* (f01+1);
%	i = denom ~= 0;
%	j = denom == 0;
%	jj = num == 0;
	measures = num./denom;
%	measures( j, 1 ) = inf;
%	measures( jj, 1 ) = 0;
	measures(measures<1) = 1./measures(measures<1);
end


if(options == 2)
	thesig = 0;
	xx = sum(tables(1,:));
	if xx < 50
		return;
	end

	c1 = fplus1.*f1plus/xx;
	c2 = fplus1.*f0plus/xx;
	c3 = fplus0.*f1plus/xx;
	c4 = fplus0.*f0plus/xx;

	five = 5;
	c = (c1>=five).*(c2>=five).*(c3>=five).*(c4>=five);

	u1 = ((f11).* (f00) - (f10) .* (f01)).^2;
	u2 = (f11) + (f00) + (f10) + (f01);
	d1 = (f11) + (f10);
	d2 = (f11) + (f01);
	d3 = (f00) + (f10);
	d4 = (f00) + (f01);
	measures = (u1.*u2)./(d1.*d2.*d3.*d4);	

%	measures(c==0) = 0;

	if(sum(isnan(measures))>0)
	%	save tetetetetetete measures u1 u2 d1 d2 d3 d4 f11 f10 f01 f00
		disp('still nan')
		
	end

end

% DiffSup

if(options == 3)
	thesig = 0;
	sup1 = (f11)./(f11+f01);
	sup2 = (f10)./(f10+f00);
	measures = abs(sup1-sup2);
end

% EP (DiffRatio)
if(options == 4)
        thesig = 0;
        sup1 = (f11)./(f11+f01);
        sup2 = (f10)./(f10+f00);
        measures = sup1./sup2;
        measures(measures<1) = 1./measures(measures<1); 
        measures(measures==Inf)=max(measures(setdiff(1:size(tables,1)',find(measures==Inf))'))+10;
end


if(ntopk~=-1)
	themeasures = sort(measures,'descend');
	measures = themeasures(1:ntopk,:);
end

if(thesig == 1)
	disp('No matched options for evaluate table');

end
