function jump_pattern_viz(datafile,snpvector)

% this function is used to visualize the pattern we discovered. It will
% include a subplot of binary pattern image and a subplot of how its subsets' 
% maximum chi-square values increase to the pattern's chi-square value. 
% example: 
% snpvector has to be a discovered pattern in the .

% load datafile
load(datafile);

for i=1:length(snpvector)
[snp geno] = strtok(snpvector{i},'(');
[geno tmp] = strtok(geno,'(');
[geno tmp] = strtok(geno,')');
tmp = find(ismember(snpRSNums,snp)==1);
colvector(i) = tmp(str2num(geno)+1);
end


% reorder the pattern based on class label
patt=trans_data(:,colvector);
[p,q]=size(patt);
patt_sum=sum(patt,2);
i1=find(classnew==0 & patt_sum~=q);
i2=find(classnew==0 & patt_sum==q);
j1=find(classnew==1 & patt_sum==q);
j2=find(classnew==1 & patt_sum~=q);
result=zeros(size(patt));
result=patt([i1;i2;j1;j2]',:);

% plot the pattern's image
set(0,'defaultaxesfontsize',16)

subplot(1,2,1)
colormap(gray(256));
imagesc(result);
xtickmax=max(str2num(get(gca,'XTickLabel')));
xtickmin=min(str2num(get(gca,'XTickLabel')));
map1 = colormap;
map = flipud(map1);       
colormap(map);
hold on

% add class label border
plot([0:size(patt,2)+1],size(find(classnew==0),1)*(ones(size(patt,2)+2,1)),'y','LineWidth',3);

% add singleton border
if (xtickmin==0.5)
    for i=xtickmin:xtickmax-2
        plot((i+1)*ones(size(classnew,1)+2,1),[-1:size(classnew,1)],'g','LineWidth',3)
    end
elseif (xtickmin==1)
    for i=xtickmin:xtickmax-1
        plot((i+0.5)*ones(size(classnew,1)+2,1),[-1:size(classnew,1)],'g','LineWidth',3)
    end
else
    display('please check XTcikLabel')
end

% add RS number/gene name for each singleton 
if (exist('snpRSNums')==1)
set(gca, 'XTick', [1:size(patt,2)], 'XTickLabel',snpRSNums(colvector)')
elseif ( exist('snpGeneNames')==1)
set(gca, 'XTick', [1:size(patt,2)], 'XTickLabel',snpGeneNames(colvector)')
else
display('No SNP RS number and Gene Name found!');
end

% add evaluation measures to the title

x = find(classnew == 0);
y = find(classnew == 1);

cases = trans_data(x,colvector);
controls = trans_data(y,colvector);

xlength=size(x,1);
ylength=size(y,1);

a=size(find(sum(cases,2)==length(colvector)),1);
c=xlength-a;
b=size(find(sum(controls,2)==length(colvector)),1);
d=ylength-b;

chi2 = evaluate_tables_gf([a b c d],2,-1);
OR = evaluate_tables_gf([a b c d],1,-1);
F_pv = 10^(-evaluate_tables_pv([a b c d]));

title(sprintf('chi2(%0.2f), OR(%0.2f), FisherPvalue(%0.5g)',chi2,OR,F_pv)); 


% plot the trend of max subsets' chi-square value 
% SubMaxK and diffsupMax also computed but not used
[p q]=size(patt);
x = find(classnew == 0);
y = find(classnew == 1);
xlength=size(x,1);
ylength=size(y,1);


for k=1:q
A=combinator(q,k,'c');
for i=1:size(A,1);
testpatt=patt(:,A(i,:));
MaxK1(i)=size(find(sum(testpatt(classnew==1,:),2)==k),1)/size(find(classnew==1),1);
MaxK2(i)=size(find(sum(testpatt(classnew==0,:),2)==k),1)/size(find(classnew==0),1);
diffsup(i)=abs(size(find(sum(testpatt(classnew==0,:),2)==k),1)/size(find(classnew==0),1) ...
      -size(find(sum(testpatt(classnew==1,:),2)==k),1)/size(find(classnew==1),1));

sub_cases=patt(classnew==0,A(i,:));
sub_controls=patt(classnew==1,A(i,:));
sub_a=size(find(sum(sub_cases,2)==k),1);
sub_c=xlength-sub_a;
sub_b=size(find(sum(sub_controls,2)==k),1);
sub_d=ylength-sub_b;
subChi2{k}(i)=evaluate_tables_gf([sub_a sub_b sub_c sub_d],2,-1);
                                      
end
diffsupmax(k)=max(diffsup);
SupMaxK1(k)=size(find(sum(patt(classnew==0,:),2)==q),1)/size(find(classnew==0),1)-max(MaxK1);
SupMaxK2(k)=size(find(sum(patt(classnew==1,:),2)==q),1)/size(find(classnew==1),1)-max(MaxK2);
MaxSubChi2(k)=max(subChi2{k});
minSubChi2(k)=min(subChi2{k});
end

% only to size 6 pattern. Can be modified for the use of larger size patterns
subplot(1,2,2)
bar([minSubChi2' MaxSubChi2'])
ylabel('Chi2 Statistic')
legend('Min','Max');
if (q==2)
    set(gca, 'XTick', [1:q], 'XTickLabel', ...
    {'Size 1', 'Size 2'});
elseif (q==3)
    set(gca, 'XTick', [1:q], 'XTickLabel', ...
    {'Size 1', 'Size 2', 'Size 3'});
elseif (q==4)
    set(gca, 'XTick', [1:q], 'XTickLabel', ...
    {'Size 1', 'Size 2', 'Size 3','Size 4'});
elseif (q==5)
    set(gca, 'XTick', [1:q], 'XTickLabel', ...
    {'Size 1', 'Size 2', 'Size 3','Size 4','Size 5'});
elseif (q==6)
    set(gca, 'XTick', [1:q], 'XTickLabel', ...
    {'Size 1', 'Size 2', 'Size 3','Size 4','Size 5','Size 6'});
else
    display('pattern size is greater than 6, please manually add column separator for the pattern');
end

end
