function  run_SMP_all(datafile,discR,eps,filter,chi2jump_cutoff,topN,FDR_cutoff,topNmax,overlap,koverlap,n)

load(datafile)

%% pattern discovery and evaluate patterns by statistical meatures

	rand_ind = genrand(size(trans_data,1),n); 

for j=0:n

	% permute class labels
	if (j==0)
		classtmp = classnew;
	else
		classtmp = classnew(rand_ind(j,:));
	end
	resultfile = run_SMP(trans_data,classtmp,discR,eps,filter,j);

	% break the function if no discriminative pattern is found from real label
	if (j==0)
		s = dir(resultfile);
		if (s.bytes == 0)
			display(sprintf('NO discriminative pattern is found, please lower discR and run again. Thanks! \n'))
			return;
		end
	end

	% generate contingency table for each pattern
	abcd = gen_abcd(datafile,resultfile,rand_ind,j);

	% compute statistics for all patterns
	resultM = textread(resultfile);
	[Chi2{j+1} OR{j+1} Fisher_negative_log10_pv{j+1} chi2jump{j+1} abcdtbl{j+1} p_size{j+1} result{j+1}]= pattern_evaluation(resultM,trans_data,classtmp,abcd,chi2jump_cutoff);

	% break the function if no jump pattern is found
	if (j==0)
		if (isempty(Chi2{j+1})==1)
			display(sprintf('NO jump pattern is found, please lower chi2_jump_cutoff and run again. Thanks! \n'))
			return;
		end
	end
	
	% remove redundant patterns if it's required
	if (overlap<1)
		pattinfo = zeros(size(result{j+1},1),size(trans_data,2));
		for i=1:size(result{j+1},1)
			pattinfo(i,result{j+1}(i,1:p_size{j+1}(i))) = 1;
		end
	
		inds = func_get_nonoverlapPatt1Dgene(pattinfo,overlap,koverlap,Chi2{j+1});
		Chi2{j+1} = Chi2{j+1}(inds);
		OR{j+1} = OR{j+1}(inds);
		Fisher_negative_log10_pv{j+1} = Fisher_negative_log10_pv{j+1}(inds);
		chi2jump{j+1} = chi2jump{j+1}(inds);
		abcdtbl{j+1} = abcdtbl{j+1}(inds,:);
		p_size{j+1} = p_size{j+1}(inds);
		result{j+1} = result{j+1}(inds,:);	
	end
end

%% compute FDR
real_measure = Chi2{1};
real_p_size = p_size{1};

random_measure = Chi2(2:end);
random_measure = cell2mat(random_measure');
random_p_size = p_size(2:end);
random_p_size = cell2mat(random_p_size');

FDR = compute_FDR_size_specific(real_measure, random_measure,real_p_size,random_p_size,n);

%% filter patterns based on requirement

freq_class_0 = abcdtbl{1}(:,1);
freq_class_1 = abcdtbl{1}(:,2);
Chi2 = Chi2{1};
OR = OR{1};
F_pv = 10.^(-Fisher_negative_log10_pv{1});
chi2_jump = chi2jump{1};
FDR = FDR';
result = result{1};

[tmp indrank] = sort(-Chi2);
[tmp chi2rank] = sort(indrank);


if ( isempty(find(FDR <= FDR_cutoff)) == 1)
	ind2keep = find(chi2rank <= topN);
elseif ( nnz(find(FDR <= FDR_cutoff)) > topNmax)
	ind2keep = find(chi2rank <= topNmax);
else
	ind2keep = find(FDR <= FDR_cutoff);
end

ind2keep = indrank(1:length(ind2keep));

freq_class_0 = freq_class_0(ind2keep);
freq_ratio_class_0 = freq_class_0/nnz(classnew==0);
freq_class_1 = freq_class_1(ind2keep);
freq_ratio_class_1 = freq_class_1/nnz(classnew==1);
Chi2 = Chi2(ind2keep);
OR = OR(ind2keep);
F_pv = F_pv(ind2keep);
chi2_jump = chi2_jump(ind2keep);
FDR = FDR(ind2keep);
result = result(ind2keep,:);
real_p_size = real_p_size(ind2keep);

result(result==0)=nan;
result_geno = rem(result,3);
result_geno = result_geno-1;
result_geno(result_geno==-1)=2;

%% print patterns and their statistical measures to text file

for i=1:size(result,1)
	result_rs{i} = snpRSNums(result(i,1:real_p_size(i)));
end

fid = fopen('Chi2_Jump_Pattern_Summary.txt','w');

filehead = {'freq_class_0','freq_class_1','Chi2','OR','F_pv','Chi2_jump','FDR','Jump_pattern'};

pattinfo = [freq_class_0 freq_ratio_class_0 freq_class_1 freq_ratio_class_1 Chi2 OR F_pv chi2_jump FDR];


[rows,cols]=size(filehead);

for i=1:rows
	fprintf(fid,'%s \t',filehead{i,1:end-1});
	fprintf(fid,'%s\n',filehead{i,end});
end

[rows,cols]=size(pattinfo);
for i=1:rows
	fprintf(fid,'%.f(%.2f) \t %.f(%.2f) \t %.2f \t %.2f \t %0.5g \t %.2f \t %.4f \t',pattinfo(i,:));
	for k=1:length(result_rs{i})-1
		fprintf(fid,'%s(%d) \t',result_rs{i}{k},result_geno(i,k));
	end
	fprintf(fid,'%s(%d) \n',result_rs{i}{end},result_geno(i,k+1));
end

fclose(fid)

system('/bin/rm result_discR*_R*')

