% Double check list:
% You have read the readme.txt and have made sure the following
% Your SNP data is in PLINK format, i.e. three files: *.bim, *.bed and *.fam, where '*' stands for a common filename.
% The number of SNPs in your data is below 3000, or you have selected a subset of less redundant SNPs with PLINK (readme.txt) 

% Input: The PLINK files, basically the common string of *.bim, *.bed and *.fam.
% Output: A text file 'Chi2_Jump_Pattern_Summary.txt' with the list of SNP combinations discovered and the statistics of associations (ranked by Chi2)
%         freq_class_0: frequency of a SNP combination in cases 
%	  freq_class_1: frequency of a SNP combination in controls
% 	  Chi2:		Chi2 statistic of the SNP combination wrt the case-control label
%         OR:		Odds ratio
% 	  F_pv:		Fisher exact test, p value 	
%	  Chi2_jump:	minimum chi2 jump (refer to the definition in the paper), how much better a SNP combination has to be, beyond its best subset
% 	  FDR:		FDR	 
%	  Jump_pattern:	the list of SNPs and genotypes(0: MM-majority homozygous, 1: Mm-heterozygous, 2: mm-minority homozygous) in each SNP combination

%%%%%%%%%% parameters that need to be double checked before running

datafile='snptestdata';				% the common string of your PLINK files *.bim, *.bed and *.fam.

discR = 0.2;					% the frequency (%) difference of a SNP combination between cases and controls
FDR_cutoff = 0.25;				% maximal FDR allowed
n=5;						% number of permutations, recommended 100 as minimum, but use a small number, e.g. 5 to test if the pipeline is working
chi2jump_cutoff = 5;				% minimum chi2 jump (refer to the definition in the paper), how much better a SNP combination has to be, beyond its best subset


%%%%%%%%% parameters that you most likely would not need to change

topN = 100;					% If no combinations meet the FDR cutoff, top 100 patterns will be output in 'Chi2_Jump_Pattern_Summary.txt'
filter = 0.8;					% Reduce this (speed up) to a smaller number to filter out SNP genotypes with very high frequency
eps = 0.25;					% This is the error-tolerant parameter: set to 0 to speed up the pattern mining process; otherwise keep it as 0.25. 
overlap = 1;					% If you notice a lot of overlap among the discovered list of significant SNP combinations, set this parameter to 0.5 or 0.33 to reduce the overlaps

%%%%%%%%% parameters for programming purpose that you do not need to change.

topNmax = 5000;					
koverlap = 0;

check_R_PLINK;

plink2mat(datafile);

run_SMP_all(datafile,discR,eps,filter,chi2jump_cutoff,topN,FDR_cutoff,topNmax,overlap,koverlap,n);

